@@ -6,8 +6,8 @@ use {
         errors::{ProgramError, TreeBuildError},
         flag::Flag,
         git,
-        pattern::*,
         path::{self, PathAnchor},
+        pattern::*,
         print,
         stage::*,
         task_sync::Dam,
@@ -24,7 +24,7 @@ use {
 pub struct BrowserState {
     pub tree: Tree,
     pub filtered_tree: Option<Tree>,
-    mode: Mode, // whether we're in 'input' or 'normal' mode
+    mode: Mode,                        // whether we're in 'input' or 'normal' mode
     pending_task: Option<BrowserTask>, // note: there are some other pending task, see
 }
 
@@ -42,7 +42,6 @@ enum BrowserTask {
 }
 
 impl BrowserState {
-
     /// build a new tree state if there's no error and there's no cancellation.
     pub fn new(
         path: PathBuf,
@@ -51,23 +50,21 @@ impl BrowserState {
         con: &AppContext,
         dam: &Dam,
     ) -> Result<BrowserState, TreeBuildError> {
-
         // on windows, canonicalize the path produces UNC paths, so we don't do it.
         // On other platforms, it's a desirable step, mainly because it simplifies the
         // paths you'd get for example when focusing a relative symlink containing "..".
         #[cfg(not(target_os = "windows"))]
         let path = path.canonicalize().unwrap_or(path);
 
-        let pending_task = options.pattern
+        let pending_task = options
+            .pattern
             .take()
             .as_option()
-            .map(|pattern| BrowserTask::Search { pattern, total: false });
-        let builder = TreeBuilder::from(
-            path,
-            options,
-            BrowserState::page_height(screen),
-            con,
-        )?;
+            .map(|pattern| BrowserTask::Search {
+                pattern,
+                total: false,
+            });
+        let builder = TreeBuilder::from(path, options, BrowserState::page_height(screen), con)?;
         let tree = builder.build_tree(false, dam)?;
         Ok(BrowserState {
             tree,
@@ -77,7 +74,11 @@ impl BrowserState {
         })
     }
 
-    fn search(&mut self, pattern: InputPattern, total: bool) {
+    fn search(
+        &mut self,
+        pattern: InputPattern,
+        total: bool,
+    ) {
         self.pending_task = Some(BrowserTask::Search { pattern, total });
     }
 
@@ -97,14 +98,11 @@ impl BrowserState {
         let mut new_state = BrowserState::new(root, options, screen, con, &Dam::unlimited());
         if let Ok(bs) = &mut new_state {
             if tree.selection != 0 {
-                bs.displayed_tree_mut().try_select_path(&tree.selected_line().path);
+                bs.displayed_tree_mut()
+                    .try_select_path(&tree.selected_line().path);
             }
         }
-        CmdResult::from_optional_browser_state(
-            new_state,
-            message,
-            in_new_panel,
-        )
+        CmdResult::from_optional_browser_state(new_state, message, in_new_panel)
     }
 
     pub fn root(&self) -> &Path {
@@ -164,7 +162,7 @@ impl BrowserState {
         } else {
             match opener::open(&target) {
                 Ok(exit_status) => {
-                    info!("open returned with exit_status {:?}", exit_status);
+                    info!("open returned with exit_status {exit_status:?}");
                     Ok(CmdResult::Keep)
                 }
                 Err(e) => Ok(CmdResult::error(format!("{e:?}"))),
@@ -193,11 +191,9 @@ impl BrowserState {
             None => CmdResult::error("no parent found"),
         }
     }
-
 }
 
 impl PanelState for BrowserState {
-
     fn tree_root(&self) -> Option<&Path> {
         Some(self.root())
     }
@@ -206,7 +202,10 @@ impl PanelState for BrowserState {
         PanelStateType::Tree
     }
 
-    fn set_mode(&mut self, mode: Mode) {
+    fn set_mode(
+        &mut self,
+        mode: Mode,
+    ) {
         self.mode = mode;
     }
 
@@ -220,14 +219,21 @@ impl PanelState for BrowserState {
         } else if self.displayed_tree().is_missing_git_status_computation() {
             Some("computing git status")
         } else {
-            self
-                .pending_task.as_ref().map(|task| match task {
-                    BrowserTask::Search{ .. } => "searching",
-                    BrowserTask::StageAll{ .. } => "staging",
-                })
+            self.pending_task.as_ref().map(|task| match task {
+                BrowserTask::Search { .. } => "searching",
+                BrowserTask::StageAll { .. } => "staging",
+            })
         }
     }
 
+    fn watchable_paths(&self) -> Vec<PathBuf> {
+        let mut paths = Vec::new();
+        for line in &self.tree.lines {
+            paths.push(line.path.clone());
+        }
+        paths
+    }
+
     fn selected_path(&self) -> Option<&Path> {
         Some(&self.displayed_tree().selected_line().path)
     }
@@ -235,7 +241,10 @@ impl PanelState for BrowserState {
     fn selection(&self) -> Option<Selection<'_>> {
         let tree = self.displayed_tree();
         let mut selection = tree.selected_line().as_selection();
-        selection.line = tree.options.pattern.pattern
+        selection.line = tree
+            .options
+            .pattern
+            .pattern
             .get_match_line_count(selection.path)
             .unwrap_or(0);
         Some(selection)
@@ -368,44 +377,47 @@ impl PanelState for BrowserState {
             }
             Internal::line_down => {
                 let count = get_arg(input_invocation, internal_exec, 1);
-                self.displayed_tree_mut().move_selection(count, page_height, true);
+                self.displayed_tree_mut()
+                    .move_selection(count, page_height, true);
                 CmdResult::Keep
             }
             Internal::line_down_no_cycle => {
                 let count = get_arg(input_invocation, internal_exec, 1);
-                self.displayed_tree_mut().move_selection(count, page_height, false);
+                self.displayed_tree_mut()
+                    .move_selection(count, page_height, false);
                 CmdResult::Keep
             }
             Internal::line_up => {
                 let count = get_arg(input_invocation, internal_exec, 1);
-                self.displayed_tree_mut().move_selection(-count, page_height, true);
+                self.displayed_tree_mut()
+                    .move_selection(-count, page_height, true);
                 CmdResult::Keep
             }
             Internal::line_up_no_cycle => {
                 let count = get_arg(input_invocation, internal_exec, 1);
-                self.displayed_tree_mut().move_selection(-count, page_height, false);
+                self.displayed_tree_mut()
+                    .move_selection(-count, page_height, false);
                 CmdResult::Keep
             }
             Internal::next_dir => {
-                self.displayed_tree_mut().try_select_next_filtered(
-                    TreeLine::is_dir,
-                    page_height,
-                );
+                self.displayed_tree_mut()
+                    .try_select_next_filtered(TreeLine::is_dir, page_height);
                 CmdResult::Keep
             }
             Internal::next_match => {
-                self.displayed_tree_mut().try_select_next_filtered(
-                    |line| line.direct_match,
-                    page_height,
-                );
+                self.displayed_tree_mut()
+                    .try_select_next_filtered(|line| line.direct_match, page_height);
                 CmdResult::Keep
             }
             Internal::next_same_depth => {
-                self.displayed_tree_mut().try_select_next_same_depth(page_height);
+                self.displayed_tree_mut()
+                    .try_select_next_same_depth(page_height);
                 CmdResult::Keep
             }
             Internal::open_stay => self.open_selection_stay_in_broot(screen, con, bang, false)?,
-            Internal::open_stay_filter => self.open_selection_stay_in_broot(screen, con, bang, true)?,
+            Internal::open_stay_filter => {
+                self.open_selection_stay_in_broot(screen, con, bang, true)?
+            }
             Internal::page_down => {
                 let tree = self.displayed_tree_mut();
                 if !tree.try_scroll(page_height as i32, page_height) {
@@ -422,10 +434,10 @@ impl PanelState for BrowserState {
             }
             Internal::panel_left => {
                 let areas = &cc.panel.areas;
-                if areas.is_first() && areas.nb_pos < con.max_panels_count  {
+                if areas.is_first() && areas.nb_pos < con.max_panels_count {
                     // we ask for the creation of a panel to the left
                     internal_focus::new_panel_on_path(
-                        self.displayed_tree().selected_line().path.to_path_buf(),
+                        self.displayed_tree().selected_line().path.clone(),
                         screen,
                         self.displayed_tree().options.clone(),
                         PanelPurpose::None,
@@ -449,7 +461,7 @@ impl PanelState for BrowserState {
                     };
                     // we ask for the creation of a panel to the right
                     internal_focus::new_panel_on_path(
-                        selected_path.to_path_buf(),
+                        selected_path.clone(),
                         screen,
                         self.displayed_tree().options.clone(),
                         purpose,
@@ -465,21 +477,18 @@ impl PanelState for BrowserState {
             Internal::panel_right_no_open => CmdResult::HandleInApp(Internal::panel_right_no_open),
             Internal::parent => self.go_to_parent(screen, con, bang),
             Internal::previous_dir => {
-                self.displayed_tree_mut().try_select_previous_filtered(
-                    TreeLine::is_dir,
-                    page_height,
-                );
+                self.displayed_tree_mut()
+                    .try_select_previous_filtered(TreeLine::is_dir, page_height);
                 CmdResult::Keep
             }
             Internal::previous_match => {
-                self.displayed_tree_mut().try_select_previous_filtered(
-                    |line| line.direct_match,
-                    page_height,
-                );
+                self.displayed_tree_mut()
+                    .try_select_previous_filtered(|line| line.direct_match, page_height);
                 CmdResult::Keep
             }
             Internal::previous_same_depth => {
-                self.displayed_tree_mut().try_select_previous_same_depth(page_height);
+                self.displayed_tree_mut()
+                    .try_select_previous_same_depth(page_height);
                 CmdResult::Keep
             }
             Internal::print_tree => {
@@ -490,18 +499,13 @@ impl PanelState for BrowserState {
                 let tree = self.displayed_tree();
                 if tree.selection > 0 {
                     let root_len = tree.root().components().count();
-                    let new_root = tree.selected_line().path
+                    let new_root = tree
+                        .selected_line()
+                        .path
                         .components()
                         .take(root_len + 1)
                         .collect();
-                    self.modified(
-                        screen,
-                        new_root,
-                        tree.options.clone(),
-                        None,
-                        bang,
-                        con,
-                    )
+                    self.modified(screen, new_root, tree.options.clone(), None, bang, con)
                 } else {
                     CmdResult::error("No selected line")
                 }
@@ -529,9 +533,9 @@ impl PanelState for BrowserState {
                         // used before this state
                         CmdResult::HandleInApp(Internal::search_again)
                     }
-                    Some(true) => {
-                        CmdResult::error("search was already total: all possible matches have been ranked")
-                    }
+                    Some(true) => CmdResult::error(
+                        "search was already total: all possible matches have been ranked",
+                    ),
                     Some(false) => {
                         self.search(self.displayed_tree().options.pattern.clone(), true);
                         CmdResult::Keep
@@ -570,21 +574,23 @@ impl PanelState for BrowserState {
                         match res {
                             Ok(()) => {
                                 let page_height = BrowserState::page_height(screen);
-                                self.displayed_tree_mut().make_selection_visible(page_height);
+                                self.displayed_tree_mut()
+                                    .make_selection_visible(page_height);
                                 CmdResult::Keep
                             }
                             Err(e) => CmdResult::DisplayError(format!("{e}")),
                         }
                     }
-                    None => {
-                        CmdResult::Keep
-                    }
+                    None => CmdResult::Keep,
                 }
             }
             Internal::stage_all_directories => {
                 let pattern = self.displayed_tree().options.pattern.clone();
                 let file_type_condition = FileTypeCondition::Directory;
-                self.pending_task = Some(BrowserTask::StageAll{pattern, file_type_condition});
+                self.pending_task = Some(BrowserTask::StageAll {
+                    pattern,
+                    file_type_condition,
+                });
                 if cc.app.stage_panel.is_none() {
                     let stage_options = self.tree.options.without_pattern();
                     CmdResult::NewPanel {
@@ -599,7 +605,10 @@ impl PanelState for BrowserState {
             Internal::stage_all_files => {
                 let pattern = self.displayed_tree().options.pattern.clone();
                 let file_type_condition = FileTypeCondition::File;
-                self.pending_task = Some(BrowserTask::StageAll{pattern, file_type_condition});
+                self.pending_task = Some(BrowserTask::StageAll {
+                    pattern,
+                    file_type_condition,
+                });
                 if cc.app.stage_panel.is_none() {
                     let stage_options = self.tree.options.without_pattern();
                     CmdResult::NewPanel {
@@ -632,13 +641,18 @@ impl PanelState for BrowserState {
                         let arg_type = SelectionType::Any; // We might do better later
                         let purpose = PanelPurpose::ArgEdition { arg_type };
                         internal_focus::new_panel_on_path(
-                            path, screen, tree_options, purpose, con, HDir::Right,
+                            path,
+                            screen,
+                            tree_options,
+                            purpose,
+                            con,
+                            HDir::Right,
                         )
                     } else {
                         // we just open a new panel on the selected path,
                         // without purpose
                         internal_focus::new_panel_on_path(
-                            self.displayed_tree().selected_line().path.to_path_buf(),
+                            self.displayed_tree().selected_line().path.clone(),
                             screen,
                             tree_options,
                             PanelPurpose::None,
@@ -648,25 +662,21 @@ impl PanelState for BrowserState {
                     }
                 }
             }
-            Internal::total_search => {
-                match self.filtered_tree.as_ref().map(|t| t.total_search) {
-                    None => {
-                        CmdResult::error("this verb can be used only after a search")
-                    }
-                    Some(true) => {
-                        CmdResult::error("search was already total: all possible matches have been ranked")
-                    }
-                    Some(false) => {
-                        self.search(self.displayed_tree().options.pattern.clone(), true);
-                        CmdResult::Keep
-                    }
+            Internal::total_search => match self.filtered_tree.as_ref().map(|t| t.total_search) {
+                None => CmdResult::error("this verb can be used only after a search"),
+                Some(true) => CmdResult::error(
+                    "search was already total: all possible matches have been ranked",
+                ),
+                Some(false) => {
+                    self.search(self.displayed_tree().options.pattern.clone(), true);
+                    CmdResult::Keep
                 }
-            }
+            },
             Internal::trash => {
-                let path = self.displayed_tree().selected_line().path.to_path_buf();
+                let path = self.displayed_tree().selected_line().path.clone();
                 info!("trash {:?}", &path);
 
-                #[cfg(feature = "trash")]
+                #[cfg(trash)]
                 match trash::delete(&path) {
                     Ok(()) => CmdResult::RefreshState { clear_cache: true },
                     Err(e) => {
@@ -675,8 +685,8 @@ impl PanelState for BrowserState {
                     }
                 }
 
-                #[cfg(not(feature = "trash"))]
-                CmdResult::DisplayError("feature not enabled or platform does not support trash".into())
+                #[cfg(not(trash))]
+                CmdResult::DisplayError("trash not supported on this platform".into())
             }
             Internal::up_tree => match self.displayed_tree().root().parent() {
                 Some(path) => internal_focus::on_path(
@@ -761,7 +771,10 @@ impl PanelState for BrowserState {
                         self.filtered_tree = Some(ft);
                     }
                 }
-                BrowserTask::StageAll { pattern, file_type_condition } => {
+                BrowserTask::StageAll {
+                    pattern,
+                    file_type_condition,
+                } => {
                     debug!("stage all pattern: {:?}", pattern);
                     let tree = self.displayed_tree();
                     let root = tree.root().clone();
@@ -769,18 +782,13 @@ impl PanelState for BrowserState {
                     let total_search = true;
                     options.pattern = pattern; // should be the same
                     let builder = TreeBuilder::from(root, options, con.max_staged_count, con);
-                    let mut paths = builder
-                        .and_then(|mut builder| {
-                            builder.matches_max = Some(con.max_staged_count);
-                            time!(builder.build_paths(
-                                total_search,
-                                dam,
-                                |line| {
-                                    debug!("??staging {:?}", &line.path);
-                                    file_type_condition.accepts_path(&line.path)
-                                }
-                            ))
-                        })?;
+                    let mut paths = builder.and_then(|mut builder| {
+                        builder.matches_max = Some(con.max_staged_count);
+                        time!(builder.build_paths(total_search, dam, |line| {
+                            debug!("??staging {:?}", &line.path);
+                            file_type_condition.accepts_path(&line.path)
+                        }))
+                    })?;
                     for path in paths.drain(..) {
                         app_state.stage.add(path);
                     }
@@ -791,7 +799,8 @@ impl PanelState for BrowserState {
             let git_status = git::get_tree_status(root_path, dam);
             self.displayed_tree_mut().git_status = git_status;
         } else {
-            self.displayed_tree_mut().fetch_some_missing_dir_sum(dam, con);
+            self.displayed_tree_mut()
+                .fetch_some_missing_dir_sum(dam, con);
         }
         Ok(())
     }
@@ -812,7 +821,11 @@ impl PanelState for BrowserState {
         dp.write_on(w)
     }
 
-    fn refresh(&mut self, screen: Screen, con: &AppContext) -> Command {
+    fn refresh(
+        &mut self,
+        screen: Screen,
+        con: &AppContext,
+    ) -> Command {
         let page_height = BrowserState::page_height(screen);
         // refresh the base tree
         if let Err(e) = self.tree.refresh(page_height, con) {
@@ -852,4 +865,3 @@ impl PanelState for BrowserState {
         }
     }
 }
-
