@@ -1,12 +1,13 @@
 use {
     super::{
-        cond_bg,
+        BRANCH_FILLING,
         Col,
         CropWriter,
         GitStatusDisplay,
         MatchedString,
+        SPACE_FILLING,
+        cond_bg,
         num_format::format_count,
-        SPACE_FILLING, BRANCH_FILLING,
     },
     crate::{
         app::AppState,
@@ -14,22 +15,37 @@ use {
         errors::ProgramError,
         file_sum::FileSum,
         pattern::PatternObject,
-        skin::{ExtColorMap, StyleMap},
+        skin::{
+            ExtColorMap,
+            StyleMap,
+        },
         task_sync::ComputationResult,
-        tree::{Tree, TreeLine, TreeLineType},
+        tree::{
+            Tree,
+            TreeLine,
+            TreeLineType,
+        },
+    },
+    chrono::{
+        DateTime,
+        Local,
+        LocalResult,
+        TimeZone,
     },
-    chrono::{DateTime, Local, LocalResult, TimeZone},
     crokey::crossterm::{
-        cursor,
         QueueableCommand,
+        cursor,
     },
     file_size,
     git2::Status,
     std::io::Write,
-    termimad::{CompoundStyle, ProgressBar},
+    termimad::{
+        CompoundStyle,
+        ProgressBar,
+    },
     unicode_width::{
-        UnicodeWidthStr,
         UnicodeWidthChar,
+        UnicodeWidthStr,
     },
 };
 
@@ -37,7 +53,7 @@ use {
 /// - to write on the screen in the application,
 /// - or to write in a file or an exported string.
 ///
-/// Using it in the application (with in_app true) means that
+/// Using it in the application (with `in_app` true) means that
 ///  - the selection is drawn
 ///  - a scrollbar may be drawn
 ///  - the empty lines will be erased
@@ -51,7 +67,6 @@ pub struct DisplayableTree<'a, 's, 't> {
 }
 
 impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
-
     pub fn out_of_app(
         tree: &'t Tree,
         skin: &'s StyleMap,
@@ -120,7 +135,7 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         })
     }
 
-    #[cfg(any(target_os="linux", target_os = "macos"))]
+    #[cfg(any(target_os = "linux", target_os = "macos"))]
     fn write_line_device_id<W: Write>(
         &self,
         cw: &mut CropWriter<W>,
@@ -138,7 +153,6 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
     }
 
     fn write_line_selection_mark<W: Write>(
-        &self,
         cw: &mut CropWriter<W>,
         style: &CompoundStyle,
         selected: bool,
@@ -152,17 +166,13 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
     }
 
     fn write_line_size<W: Write>(
-        &self,
         cw: &mut CropWriter<W>,
         line: &TreeLine,
         style: &CompoundStyle,
         _selected: bool,
     ) -> Result<usize, termimad::Error> {
         Ok(if let Some(s) = line.sum {
-            cw.queue_g_string(
-                style,
-                format!("{:>4}", file_size::fit_4(s.to_size())),
-            )?;
+            cw.queue_g_string(style, format!("{:>4}", file_size::fit_4(s.to_size())))?;
             1
         } else {
             5
@@ -182,13 +192,14 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         Ok(if let Some(s) = line.sum {
             let pb = ProgressBar::new(s.part_of_size(total_size), 10);
             cond_bg!(sparse_style, self, selected, self.skin.sparse);
-            cw.queue_g_string(
-                label_style,
-                format!("{:>4}", file_size::fit_4(s.to_size())),
-            )?;
+            cw.queue_g_string(label_style, format!("{:>4}", file_size::fit_4(s.to_size())))?;
             cw.queue_char(
                 sparse_style,
-                if s.is_sparse() && line.is_file() { 's' } else { ' ' },
+                if s.is_sparse() && line.is_file() {
+                    's'
+                } else {
+                    ' '
+                },
             )?;
             cw.queue_g_string(label_style, format!("{pb:<10}"))?;
             1
@@ -250,28 +261,22 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         cond_bg!(branch_style, self, selected, self.skin.tree);
         let mut branch = String::new();
         for depth in 0..line.depth {
-            branch.push_str(
-                if line.left_branches[depth as usize] {
-                    if self.tree.has_branch(line_index + 1, depth as usize) {
-                        // TODO: If a theme is on, remove the horizontal lines
-                        if depth == line.depth - 1 {
-                            if staged {
-                                "├◍─"
-                            } else {
-                                "├──"
-                            }
-                        } else {
-                            "│  "
-                        }
-                    } else if staged {
-                        "└◍─"
+            branch.push_str(if line.left_branches[depth as usize] {
+                if self.tree.has_branch(line_index + 1, depth as usize) {
+                    // TODO: If a theme is on, remove the horizontal lines
+                    if depth == line.depth - 1 {
+                        if staged { "├◍─" } else { "├──" }
                     } else {
-                        "└──"
+                        "│  "
                     }
+                } else if staged {
+                    "└◍─"
                 } else {
-                    "   "
-                },
-            );
+                    "└──"
+                }
+            } else {
+                "   "
+            });
         }
         if !branch.is_empty() {
             cw.queue_g_string(branch_style, branch)?;
@@ -281,7 +286,6 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
 
     /// write the symbol showing whether the path is staged
     fn write_line_stage_mark<W: Write>(
-        &self,
         cw: &mut CropWriter<W>,
         style: &CompoundStyle,
         staged: bool,
@@ -294,7 +298,7 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         })
     }
 
-    /// write the name or subpath, depending on the pattern_object
+    /// write the name or subpath, depending on the `pattern_object`
     fn write_line_label<W: Write>(
         &self,
         cw: &mut CropWriter<W>,
@@ -311,14 +315,9 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         }
         if pattern_object.subpath {
             if self.tree.options.show_matching_characters_on_path_searches && line.unlisted == 0 {
-                let name_match = self.tree.options.pattern.pattern
-                    .find_string(&line.subpath);
-                let mut path_ms = MatchedString::new(
-                    name_match,
-                    &line.subpath,
-                    style,
-                    char_match_style,
-                );
+                let name_match = self.tree.options.pattern.pattern.find_string(&line.subpath);
+                let mut path_ms =
+                    MatchedString::new(name_match, &line.subpath, style, char_match_style);
                 let name_ms = path_ms.split_on_last('/');
                 cond_bg!(parent_style, self, selected, self.skin.parent);
                 if let Some(name_ms) = name_ms {
@@ -341,14 +340,9 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
                 cw.queue_str(style, &line.name)?;
             }
         } else {
-            let name_match = self.tree.options.pattern.pattern
-                .find_string(&line.name);
-            let matched_string = MatchedString::new(
-                name_match,
-                &line.name,
-                style,
-                char_match_style,
-            );
+            let name_match = self.tree.options.pattern.pattern.find_string(&line.name);
+            let matched_string =
+                MatchedString::new(name_match, &line.name, style, char_match_style);
             matched_string.queue_on(cw)?;
         }
         match &line.line_type {
@@ -384,7 +378,7 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
     fn write_content_extract<W: Write>(
         &self,
         cw: &mut CropWriter<W>,
-        extract: ContentMatch,
+        extract: &ContentMatch,
         selected: bool,
     ) -> Result<(), ProgramError> {
         cond_bg!(extract_style, self, selected, self.skin.content_extract);
@@ -412,10 +406,7 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         let line = &self.tree.lines[0];
         if self.tree.options.show_sizes {
             if let Some(s) = line.sum {
-                cw.queue_g_string(
-                    style,
-                    format!("{:>4} ", file_size::fit_4(s.to_size())),
-                )?;
+                cw.queue_g_string(style, format!("{:>4} ", file_size::fit_4(s.to_size())))?;
             }
         }
         let title = line.path.to_string_lossy();
@@ -442,21 +433,14 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
 
         if self.in_app && !cw.is_full() {
             if let ComputationResult::Done(git_status) = &self.tree.git_status {
-                let git_status_display = GitStatusDisplay::from(
-                    git_status,
-                    self.skin,
-                    cw.allowed,
-                );
+                let git_status_display = GitStatusDisplay::from(git_status, self.skin, cw.allowed);
                 git_status_display.write(cw, selected)?;
             }
-            #[cfg(any(target_os="linux", target_os = "macos"))]
+            #[cfg(any(target_os = "linux", target_os = "macos"))]
             if self.tree.options.show_root_fs {
                 if let Some(mount) = line.mount() {
-                    let fs_space_display = crate::filesystems::MountSpaceDisplay::from(
-                        &mount,
-                        self.skin,
-                        cw.allowed,
-                    );
+                    let fs_space_display =
+                        crate::filesystems::MountSpaceDisplay::from(&mount, self.skin, cw.allowed);
                     fs_space_display.write(cw, selected)?;
                 }
             }
@@ -483,7 +467,10 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
     }
 
     /// write the whole tree on the given `W`
-    pub fn write_on<W: Write>(&self, f: &mut W) -> Result<(), ProgramError> {
+    pub fn write_on<W: Write>(
+        &self,
+        f: &mut W,
+    ) -> Result<(), ProgramError> {
         #[cfg(not(any(target_family = "windows", target_os = "android")))]
         let perm_writer = super::PermWriter::for_tree(self.skin, self.tree);
 
@@ -512,12 +499,13 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
             .cols_order
             .iter()
             .filter(|col| col.is_visible(tree, self.app_state))
-            .cloned()
+            .copied()
             .collect();
 
         // if necessary we compute the width of the count column
         let count_len = if tree.options.show_counts {
-            tree.lines.iter()
+            tree.lines
+                .iter()
                 .skip(1) // we don't show the counts of the root
                 .map(|l| l.sum.map_or(0, |s| s.to_count()))
                 .max()
@@ -530,7 +518,10 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         // we compute the length of the dates, depending on the format
         let date_len = if tree.options.show_dates {
             let date_time: DateTime<Local> = Local::now();
-            date_time.format(tree.options.date_time_format).to_string().len()
+            date_time
+                .format(tree.options.date_time_format)
+                .to_string()
+                .len()
         } else {
             0 // we don't care
         };
@@ -561,18 +552,14 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
                 if visible_cols[0].needs_left_margin() {
                     cw.queue_char(space_style, ' ')?;
                 }
-                let staged = self.app_state
+                let staged = self
+                    .app_state
                     .map_or(false, |a| a.stage.contains(&line.path));
                 for col in &visible_cols {
                     let void_len = match col {
+                        Col::Mark => Self::write_line_selection_mark(cw, &label_style, selected)?,
 
-                        Col::Mark => {
-                            self.write_line_selection_mark(cw, &label_style, selected)?
-                        }
-
-                        Col::Git => {
-                            self.write_line_git_status(cw, line, selected)?
-                        }
+                        Col::Git => self.write_line_git_status(cw, line, selected)?,
 
                         Col::Branch => {
                             in_branch = true;
@@ -580,16 +567,20 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
                         }
 
                         Col::DeviceId => {
-                            #[cfg(not(any(target_os="linux", target_os = "macos")))]
-                            { 0 }
+                            #[cfg(not(any(target_os = "linux", target_os = "macos")))]
+                            {
+                                0
+                            }
 
-                            #[cfg(any(target_os="linux", target_os = "macos"))]
+                            #[cfg(any(target_os = "linux", target_os = "macos"))]
                             self.write_line_device_id(cw, line, selected)?
                         }
 
                         Col::Permission => {
                             #[cfg(any(target_family = "windows", target_os = "android"))]
-                            { 0 }
+                            {
+                                0
+                            }
 
                             #[cfg(not(any(target_family = "windows", target_os = "android")))]
                             perm_writer.write_permissions(cw, line, selected)?
@@ -606,25 +597,26 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
                         Col::Size => {
                             if tree.options.sort.prevent_deep_display() {
                                 // as soon as there's only one level displayed we can show the size bars
-                                self.write_line_size_with_bar(cw, line, &label_style, total_size, selected)?
+                                self.write_line_size_with_bar(
+                                    cw,
+                                    line,
+                                    &label_style,
+                                    total_size,
+                                    selected,
+                                )?
                             } else {
-                                self.write_line_size(cw, line, &label_style, selected)?
+                                Self::write_line_size(cw, line, &label_style, selected)?
                             }
                         }
 
-                        Col::Count => {
-                            self.write_line_count(cw, line, count_len, selected)?
-                        }
+                        Col::Count => self.write_line_count(cw, line, count_len, selected)?,
 
-                        Col::Staged => {
-                            self.write_line_stage_mark(cw, &label_style, staged)?
-                        }
+                        Col::Staged => Self::write_line_stage_mark(cw, &label_style, staged)?,
 
                         Col::Name => {
                             in_branch = false;
                             self.write_line_label(cw, line, &label_style, pattern_object, selected)?
                         }
-
                     };
                     // void: intercol & replacing missing cells
                     if in_branch && void_len > 2 {
@@ -637,10 +629,13 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
                 }
 
                 if cw.allowed > 8 && pattern_object.content {
-                    let extract = tree.options.pattern.pattern
+                    let extract = tree
+                        .options
+                        .pattern
+                        .pattern
                         .find_content(&line.path, cw.allowed - 2);
                     if let Some(extract) = extract {
-                        self.write_content_extract(cw, extract, selected)?;
+                        self.write_content_extract(cw, &extract, selected)?;
                     }
                 }
             }
@@ -664,4 +659,3 @@ impl<'a, 's, 't> DisplayableTree<'a, 's, 't> {
         Ok(())
     }
 }
-
